rm(list = ls()); gc()

args <- commandArgs(trailingOnly = TRUE)

setwd("/esarchive/scratch/nmilders/gitlab/git_clones/auto-s2s/")
recipe_file <- "recipes/recipe_scorecards_nadia_testing.yml"

source("modules/Loading/Loading_freq_comp.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("tools/prepare_outputs.R")

recipe <- prepare_outputs(recipe_file)

## Run job for each start month
recipe$Analysis$Time$sdate <- paste0(sprintf("%02d", as.numeric(args)), '01')

## Load datasets
data <- load_datasets(recipe)
gc()


## select start month from dates_file
smonth <- substr(recipe$Analysis$Time$sdate, 1,2)

archive <- read_yaml("conf/archive.yml")$esarchive
regrid_params <- get_regrid_params(recipe, archive)

lats.min <- recipe$Analysis$Region$latmin
lats.max <- recipe$Analysis$Region$latmax
lons.min <- recipe$Analysis$Region$lonmin
lons.max <- recipe$Analysis$Region$lonmax

obs <- readRDS(paste0('/esarchive/scratch/nmilders/frequency_comparison/data/data6hr_monthlymean_sdate',smonth,'.rds'))

# Need to regrid obs to grid of exp
aux <- CDORemap(data_array = obs$output, 
                lons = obs$lon, lats = obs$lat, 
                grid = regrid_params$obs.gridtype, method = recipe$Analysis$Regrid$method, 
                avoid_writes = TRUE, crop = c(lons.min, lons.max,lats.min, lats.max),
                force_remap = TRUE)

obs$output <- aux$data_array   
obs$lon <- aux$lons
obs$lat <- aux$lats
rm(aux)

for(ftime in 2:recipe$Analysis$Time$ftime_max){
  forecast.month <- as.numeric(smonth) + (ftime -1)
  
  filepath <- paste0('/esarchive/scratch/nmilders/frequency_comparison/data/data6hr_monthlymean_sdate',sprintf("%02d", forecast.month),'.rds')
  
  if(forecast.month > 12){
    forecast.month <- forecast.month - 12
    
    filepath <- paste0('/esarchive/scratch/nmilders/frequency_comparison/data/data6hr_monthlymean_sdate',sprintf("%02d", forecast.month),'_1994-2017.rds')
  }

  print(forecast.month)
  print(filepath)
  
  obs_ftime_temp <- readRDS(filepath)
  
  # Need to regrid obs to grid of exp
  aux <- CDORemap(data_array = obs_ftime_temp$output, 
                  lons = obs_ftime_temp$lon, lats = obs_ftime_temp$lat, 
                  grid = regrid_params$obs.gridtype, method = recipe$Analysis$Regrid$method, 
                  avoid_writes = TRUE, crop = c(lons.min, lons.max,lats.min, lats.max),
                  force_remap = TRUE)
  
  obs_ftime_temp$output <- aux$data_array   
  # obs_ftime_temp$lon <- aux$lons
  # obs_ftime_temp$lat <- aux$lats
  rm(aux)
  
  obs$output <- abind(obs$output, obs_ftime_temp$output, along = 4)
}

names(dim(obs$output))[1] <- 'dat'
names(dim(obs$output))[2] <- 'var'
names(dim(obs$output))[3] <- 'syear'
names(dim(obs$output))[4] <- 'time'
names(dim(obs$output))[5] <- 'latitude'
names(dim(obs$output))[6] <- 'longitude'
obs$output <- InsertDim(obs$output, posdim = 3, lendim = 1, name = 'sday')
obs$output <- InsertDim(obs$output, posdim = 4, lendim = 1, name = 'sweek')
obs$output <- InsertDim(obs$output, posdim = 9, lendim = 1, name = 'ensemble')

data$obs$data <- obs$output

## compute anomalies
data <- compute_anomalies(recipe, data)
gc()

## Compute skill metrics of data
skill_metrics <- compute_skill_metrics(recipe, data)
gc()


######################### PLOTS #############################


# 
# png(filename = '/esarchive/scratch/nmilders/aggregated_significance/RPS_cross_val_sdate1_reg1.png')
# years <- 1:24
# score <- rps_spatial_aggr
# plot(years, score,  col = 'orange', type = 'b', lwd = 2, main = 'Extratropical NH, January, cross-validation') ##ylim = c(280, 286),
# lines(1:24, rps_clim_spatial_aggr, col ='blue', type='b', lwd = 2)
# legend('topright',c('rps', 'rps_clim'), col = c('orange','blue'), lwd = 2)
# dev.off()
